AppConstants class
Centralized constants for the Flutter Share Pro application.
This class contains all application-wide constants including app information, author details, repository URLs, and default values.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appDescription → const String
- appName → const String
- appVersion → const String
- baseUrl → const String
- defaultTimeout → const Duration
- genericErrorMessage → const String
- iconsPath → const String
- imagesPath → const String
- maxFileSize → const int
- maxImageSize → const int
- networkErrorMessage → const String
- permissionErrorMessage → const String
- repositoryUrl → const String
- shortTimeout → const Duration