CustomSharingService class

Custom sharing service that provides WASM-compatible sharing functionality without depending on share_plus or dart:io

Constructors

CustomSharingService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isSupported bool
Check if sharing is supported on current platform
no setter
sharingMethod String
Get the sharing method for current platform
no setter

Static Methods

shareFile({required String filePath, String? text, String? subject}) Future<bool>
Share file using platform-appropriate methods
shareImage({required String imagePath, String? text, String? subject}) Future<bool>
Share image using platform-appropriate methods
shareText({required String text, String? subject, String? title}) Future<bool>
Share text content using platform-appropriate methods
shareUrl({required String url, String? text, String? subject}) Future<bool>
Share URL using platform-appropriate methods