SharingService class abstract

Abstract sharing service interface

Implementers

Constructors

SharingService()

Properties

hashCode int
The hash code for this object.
no setterinherited
isSupported bool
Check if sharing is supported on current platform
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareContent({required String content, String? subject, String? title}) Future<bool>
Share content with the given parameters
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited